import { CSSStyle } from './Props.types';
export type ComponentCategory = 'atoms' | 'layouts' | 'inputs' | 'molecules' | 'data' | 'organisms' | 'functionalities';
export type RenderMap<T> = {
    /** */
    name: string;
    /** */
    category: ComponentCategory;
    /** */
    web: (props: T, indent?: number) => CodeSample<WebRenderLanguage>;
    /** */
    react_native?: (props: T, indent?: number) => CodeSample<'react_native'>;
    /** */
    css?: (props: T, indent?: number) => CodeSample<'css'>;
    /** */
    vue?: (props: T, indent?: number) => CodeSample<'vue'>;
    /** */
    react?: (props: T, indent?: number) => CodeSample<'react'>;
    /** */
    slots: string[];
};
export type Component_Props<T extends Record<string, any>> = {
    [Key in keyof T]: {
        boundVariables: {};
        type: "VARIANT";
        value: T[Key];
    };
};
export type CodeProps_Slots<P, T extends string> = Omit<P, T> & {
    [K in T]?: (K extends keyof P ? (any[] extends P[K] ? P[K] : P[K] | CodeSample) : string | CodeSample);
} & {
    slotted?: {
        [K in T]?: boolean;
    };
    style?: CSSStyle;
};
export type CodeSample<T extends RenderLanguage = RenderLanguage> = (framework: T, indent?: number) => string;
export type WebRenderLanguage = 'web' | 'angular' | 'react' | 'vue';
export type CSSRenderLanguage = 'css' | 'react_css' | 'vue_css';
export type RenderLanguage = CSSRenderLanguage | WebRenderLanguage | 'react_native';
