import { Arr, ExtendedTypes, Obj } from '../typescript';
/**
 * Checks if the provided value is an array.
 *
 * @param arr - The value to check.
 * @returns A boolean indicating whether the value is an array.
 */
export declare function isArray(arr: unknown): arr is Arr;
/**
 * Checks if the provided value is an array and empty.
 *
 * @param arr - The array to be checked.
 * @returns `true` if the value is an empty array, `false` otherwise.
 */
export declare function isEmptyArray(arr: unknown): arr is any[] & {
    length: 0;
};
/**
 * Checks if the given array is an array of numbers.
 *
 * @param arr - The array to be checked.
 * @returns `true` if the value is an array of numbers, `false` otherwise.
 */
export declare function isArrayOfNumbers(arr: unknown): arr is number[];
/**
 * Checks if the given value is an array of strings.
 *
 * @param arr - The value to check.
 * @returns `true` if the value is an array of strings, `false` otherwise.
 */
export declare function isArrayOfStrings(arr: unknown): arr is string[];
/**
 * Checks if the given array is an array of objects.
 *
 * @param arr - The array to check.
 * @returns `true` if the array is an array of objects, `false` otherwise.
 */
export declare function isArrayOfObjects(arr: unknown): arr is Obj[];
/**
 * Checks if the given array is an array of booleans.
 *
 * @param arr - The array to check.
 * @returns `true` if the array is an array of booleans, `false` otherwise.
 */
export declare function isArrayOfBooleans(arr: unknown): arr is boolean[];
/**
 * Checks if the given array is a matrix.
 * A matrix is defined as a two-dimensional array where each element is an array.
 *
 * @param arr - The array to check.
 * @returns True if the array is a matrix, false otherwise.
 */
export declare function isMatrix(arr: unknown): arr is Arr[];
/**
 * Infers the types of elements in an array, returning a list with the types.
 *
 * @param arr - The array to infer types from.
 * @returns An array of inferred types.
 */
export declare function inferTypeOfArray(arr: Arr): ExtendedTypes[];
