import { TDateISO, TDateISODate, TDateISOTime } from '../typescript';
/**
 * Checks if a given date falls on a weekend.
 *
 * @param date - The date to check.
 * @returns `true` if the date falls on a weekend, `false` otherwise.
 */
export declare function isWeekend(date: Date): boolean;
/**
 * Checks if a given string is in the ISO date format (YYYY-MM-DD).
 *
 * @param date - The string to be checked.
 * @returns A boolean indicating whether the string is in the ISO date format.
 */
export declare function isISODate(date: string): date is TDateISODate;
/**
 * Checks if the given string is in ISO 8601 date-time format.
 *
 * @param date - The string to be checked.
 * @returns A boolean indicating whether the string is in ISO 8601 date-time format.
 */
export declare function isISODateTime(date: string): date is TDateISO;
/**
 * Checks if a given date string is in the week format (YYYY-Www).
 *
 * @param date - The date string to check.
 * @returns A boolean indicating whether the date string is in the week format.
 */
export declare function isWeekFormat(date: string): date is `${number}-W${number}`;
/**
 * Checks if the given date string is in the format of "YYYY-MM".
 *
 * @param date - The date string to check.
 * @returns A boolean indicating whether the date string is in the "YYYY-MM" format.
 */
export declare function isMonthFormat(date: string): date is `${number}-${number}`;
/**
 * Checks if the given string is in ISO time format (HH:mm.sss).
 *
 * @param date - The string to check.
 * @returns A boolean indicating whether the string is in ISO time format.
 */
export declare function isISOTime(date: string): date is TDateISOTime;
