/**
 * Toggles the value of an attribute on an HTML element.
 * If the value is not null or undefined, the attribute is set with the provided value.
 * If the value is null or undefined, the attribute is removed.
 *
 * @template T - The type of the HTML element.
 * @template K - The key of the attribute in the HTML element.
 * @param {T} element - The HTML element.
 * @param {K} attrName - The name of the attribute.
 * @param {T[K]} value - The value to set for the attribute.
 */
export declare function toggleAttribute<T extends HTMLElement, K extends keyof T>(element: T, attrName: K, value: T[K]): void;
/**
 * Binds an input element's change event to a callback function.
 *
 * @template T - The type of the input element's model.
 * @param {HTMLElement & { value: T; }} element - The input element to bind.
 * @param {(value: T) => void} callback - The callback function to be called when the input element's model changes.
 */
export declare function bindInputChange<T>(element: HTMLElement & {
    model: T;
}, callback: (model: T) => void): void;
