import { MapOfAny, Obj } from '../typescript';
/**
 * Checks if the provided value is an instance of `Map`.
 *
 * @param map - The value to check.
 * @returns Returns `true` if the value is an instance of `Map`, `false` otherwise.
 */
export declare function isMap(map: unknown): map is MapOfAny;
/**
 * Checks if the given map is a `Map` where the keys are objects.
 *
 * @param map - The map to check.
 * @returns A `boolean` indicating whether the map is a `Map` with object keys.
 */
export declare function isObjectKeyMap(map: unknown): map is Map<Obj, unknown>;
/**
 * Checks if the provided value is a `Map` with `string` keys.
 *
 * @param map - The value to check.
 * @returns `true` if the value is a `Map` with `string` keys, `false` otherwise.
 */
export declare function isStringKeyMap(map: unknown): map is Map<string, unknown>;
/**
 * Checks if the provided value is a `Map` with `number` keys.
 *
 * @param map - The value to check.
 * @returns `true` if the value is a `Map` with `number` keys, `false` otherwise.
 */
export declare function isNumberKeyMap(map: unknown): map is Map<number, unknown>;
/**
 * Checks if the provided value is a `Map` with `string` or `number` keys.
 *
 * @param map - The value to check.
 * @returns `true` if the value is a `Map` with `string` or `number` keys, `false` otherwise.
 */
export declare function isStringOrNumberKeyMap(map: unknown): map is Map<string | number, unknown>;
