import { Arr, Dict, Obj } from '../typescript';
/**
 * Checks if the given value is an object.
 *
 * @param obj - The value to check.
 * @returns A `boolean` indicating whether the value is an object or not.
 */
export declare function isObject(obj: unknown): obj is Obj;
/**
 * Checks if the given object is an empty object.
 *
 * @param obj - The object to check.
 * @returns A `boolean` indicating whether the object is empty or not.
 */
export declare function isEmptyObject(obj: unknown): obj is {};
/**
 * Checks if the given object is a dictionary (`object`) where all values of type `string`.
 *
 * @param obj - The object to check.
 * @returns A `boolean` indicating whether the object is a dictionary of type `string`.
 */
export declare function isDictOfStrings(obj: unknown): obj is Dict<string>;
/**
 * Checks if the given object is a dictionary (`object`) with values of type `number`.
 *
 * @param obj - The object to be checked.
 * @returns A `boolean` indicating whether the object is a dictionary of type `number`.
 */
export declare function isDictOfNumbers(obj: unknown): obj is Dict<number>;
/**
 * Checks if the given object is a dictionary (`object`) with values of type `boolean`.
 *
 * @param obj - The object to be checked.
 * @returns A `boolean` indicating whether the object is a dictionary of type `boolean`.
 */
export declare function isDictOfBooleans(obj: unknown): obj is Dict<boolean>;
/**
 * Checks if the given object is a dictionary (`object`) with values of type `object`.
 *
 * @param obj - The object to be checked.
 * @returns A `boolean` indicating whether the object is a dictionary of type `object`.
 */
export declare function isDictOfObjects(obj: unknown): obj is Dict<Obj>;
/**
 * Checks if the given object is a dictionary (`object`) with values of type `array`.
 *
 * @param obj - The object to be checked.
 * @returns A `boolean` indicating whether the object is a dictionary of type `array`.
 */
export declare function isDictOfArrays(obj: unknown): obj is Dict<Arr>;
/**
 * Checks if a value is a primitive type (`string`, `number`, `boolean`, or `null`).
 *
 * @param value - The value to check.
 * @returns `true` if the value is a primitive type, `false` otherwise.
 */
export declare function isPrimitive(value: unknown): value is number | string | boolean | null;
/**
 * Checks if a value is a nullish type (`undefined` or `null`).
 *
 * @param value - The value to check.
 * @returns `true` if the value is a nullish type, `false` otherwise.
 */
export declare function isNullish(value: unknown): value is undefined | null;
/**
 * Checks if a value is a primitive type (`string`, `number`, or `boolean`).
 *
 * @param value - The value to check.
 * @returns `true` if the value is a primitive type, `false` otherwise.
 */
export declare function isNonNullablePrimitive(value: unknown): value is number | string | boolean;
