import { Obj } from '../typescript/Object.types';
type StrOrNumber = string | number;
/**
 * Returns an array of keys from the given object.
 *
 * @param obj - The object from which to extract the keys.
 *
 * @returns - An array of keys from the object.
 *
 * @template K - The type of the keys in the object.
 */
export declare function objectKeys<K extends StrOrNumber>(obj: Record<K, unknown>): K[];
/**
 * Returns an array of values from the given object.
 *
 * @param obj - The object from which to extract the values.
 *
 * @returns An array of values from the object.
 *
 * @template V - The type of the object values.
 */
export declare function objectValues<V>(obj: Record<StrOrNumber, V>): V[];
export declare function objectEntries<K extends StrOrNumber, V>(obj: Record<K, V>): [K, V][];
/**
 * Converts an object to a Map.
 *
 * @param obj - The object to convert to a Map.
 *
 * @returns A Map containing the key-value pairs from the object.
 *
 * @template K - The type of the keys in the object.
 * @template T - The type of the values in the object.
 */
export declare function objectToMap<K extends StrOrNumber, T>(obj: Record<K, T>): Map<K, T>;
/**
 * Checks if two objects are equal by comparing their stringified representations.
 *
 * @param object1 - The first object to compare.
 * @param object2 - The second object to compare.
 * @returns A boolean indicating whether the objects are equal.
 */
export declare function objectsAreEqual(object1: Obj, object2: Obj): boolean;
/**
 * Deep merge two objects.
 * @param target
 * @param ...sources
 */
export declare function mergeDeep(target: Obj, ...sources: Obj[]): Obj;
/**
 * Returns the key of the given value in the object.
 *
 * @param object - The object in which to search for the value.
 * @param value - The value to search for in the object.
 */
export declare function getKeyByValue(object: Obj, value: unknown): string | undefined;
export {};
