import { Str } from '@rimbu/typical';
import { HTTP_URL } from '../typescript';
/**
 * Determines the true type of the given object.
 *
 * @param obj - The object to determine the type of.
 * @returns The true type of the object as a string.
 */
export declare function trueTypeOf(obj: unknown): 'string' | 'number' | 'boolean' | 'array' | 'object' | 'null' | 'undefined' | 'function';
/**
 * Checks if the provided value is a string.
 *
 * @param str - The value to check.
 * @returns A `boolean` indicating whether the value is a string or not.
 */
export declare function isString(str: unknown): str is string;
/**
 * Checks if the provided value is a single character string.
 *
 * @param str - The value to check.
 * @returns A `boolean` indicating whether the value is a single character string.
 */
export declare function isChar(str: unknown): str is string & {
    length: 1;
};
/**
 * Checks if a given string is a valid HTTP URL.
 *
 * @param str - The string to be checked.
 * @returns A `boolean` indicating whether the string is a valid HTTP URL.
 */
export declare function isHTTP_URL(str: unknown): str is HTTP_URL;
/**
 * Checks if a string is not empty.
 *
 * @param str - The string to check.
 * @returns A `boolean` indicating whether the string is not empty.
 * @template T - The type of the string.
 * @remarks This function is a type guard that narrows down the type of the string to a non-empty string.
 *
 * @example
 * ```typescript
 * const result = isNotEmptyString('hello'); // result: true
 * ```
 */
export declare function isNotEmptyString<T extends string>(str: T): str is T & Str.NonEmptyString<T>;
/**
 * Checks if a value is one of the specified values.
 *
 * @param value - The value to check.
 * @param values - An array of values to compare against.
 * @returns `true` if the value is one of the specified values, `false` otherwise.
 * @typeParam T - The type of the values in the array.
 */
export declare function isOneOf<T extends string>(value: string, values: T[]): value is T;
