import { ReplaceAllIf } from '../typescript';
/**
 * Replaces all underscores (`_`) in the given text with spaces (` `).
 *
 * @param text - The input text with underscores to be replaced.
 *
 * @returns The modified text with spaces instead of underscores.
 *
 * @template T - The type of the input text.
 */
export declare function underscorePerSpace<T extends string>(text: T): ReplaceAllIf<T, '_', ' '>;
/**
 * Replaces all spaces (` `) in the given text with underscores (`_`).
 *
 * @param text - The input text with spaces to be replaced.
 *
 * @returns The modified text with underscores instead of spaces.
 *
 * @template T - The type of the input text.
 */
export declare function spacePerUnderScore<T extends string>(text: T): ReplaceAllIf<T, ' ', '_'>;
/**
 * Replaces all hyphens (`-`) in the given text with spaces (` `).
 *
 * @param text - The input text with hyphens to be replaced.
 *
 * @returns The modified text with spaces instead of hyphens.
 *
 * @template T - The type of the input text.
 */
export declare function hyphenPerSpace<T extends string>(text: T): ReplaceAllIf<T, '-', ' '>;
/**
 * Replaces all spaces (` `) in the given text with hyphens (`-`).
 *
 * @param text - The input text with spaces to be replaced.
 *
 * @returns The modified text with hyphens instead of spaces.
 *
 * @template T - The type of the input text.
 */
export declare function spacePerHyphen<T extends string>(text: T): ReplaceAllIf<T, ' ', '-'>;
