import { Locale } from './languages.types';
/**
 * Represents a collection of language codes and their corresponding names.
 *
 * @remarks
 * The keys of this object are language codes, and the values are the names of the languages.
 * The language codes follow the [ISO 639-1 standard](https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes).
 */
export declare const LANGUAGES: {
    ar: string;
    ca: string;
    da: string;
    de: string;
    en: string;
    'en-UK': string;
    'en-US': string;
    es: string;
    eu: string;
    fr: string;
    gl: string;
    hi: string;
    id: string;
    it: string;
    jp: string;
    ko: string;
    nl: string;
    pl: string;
    pt: string;
    ta: string;
    th: string;
    ur: string;
    vi: string;
    zh: string;
};
/**
 * Represents a mapping of locales to their corresponding `Intl.Locale` objects.
 *
 * @typedef LOCALES
 * @property en - The English locale.
 * @property en-UK - The British English locale.
 * @property en-US - The American English locale.
 * @property es - The Spanish locale.
 * @property ca - The Catalan locale.
 * @property gl - The Galician locale.
 * @property eu - The Basque locale.
 * @property de - The German locale.
 * @property nl - The Dutch locale.
 * @property da - The Danish locale.
 * @property ar - The Arabic locale.
 * @property fr - The French locale.
 * @property pl - The Polish locale.
 * @property th - The Thai locale.
 * @property ur - The Urdu locale.
 * @property hi - The Hindi locale.
 * @property vi - The Vietnamese locale.
 * @property ta - The Tamil locale.
 * @property it - The Italian locale.
 * @property pt - The Portuguese locale.
 * @property ko - The Korean locale.
 * @property jp - The Japanese locale.
 * @property id - The Indonesian locale.
 * @property zh - The Chinese locale.
 */
export declare const LOCALES: {
    [L in Locale]: Intl.Locale;
};
