import { ClassType, Func, MethodName, StaticMethodName } from './typescript';
/**
 *
 * @example
 * ```ts
 * import { MyClass } from './MyClass.model.ts';
 *
 * describe(aClass(MyClass), () => {
 *   // tests ...
 * })
 * ```
 */
export declare function aClass(className: ClassType | Func): string;
/**
 *
 * @example
 * ```ts
 * import { MyClass } from './MyClass.model.ts';
 *
 * describe(aClass(MyClass), () => {
 *   describe(aStaticMethod(MyClass, 'myStaticMethod'), () => {
 *     it(`does what it's intended`, () => {
 *       // test...
 *     })
 *   })
 * })
 * ```
 */
export declare function aStaticMethod<C extends ClassType, M extends StaticMethodName<C>>(_className: C, method: M): string;
/**
 *
 * @example
 * ```ts
 * import { MyClass } from './MyClass.model.ts';
 *
 * describe(aClass(MyClass), () => {
 *   describe(aMethod(MyClass, 'myMethod'), () => {
 *     it(`does what it's intended`, () => {
 *       // test...
 *     })
 *   })
 * })
 * ```
 */
export declare function aMethod<C extends ClassType | Func, M extends MethodName<C>>(_className: C, method: M): string;
/**
 *
 * @example
 * ```ts
 * import { MyClass } from './MyClass.model.ts';
 *
 * describe(aClass(MyClass), () => {
 *   describe(aGetter(MyClass, 'myGetter'), () => {
 *     it(`does what it's intended`, () => {
 *       // test...
 *     })
 *   })
 * })
 * ```
 */
export declare function aGetter<C extends ClassType | Func, M extends MethodName<C>>(_className: C, method: M): string;
/**
 *
 * @example
 * ```ts
 * import { MyClass } from './MyClass.model.ts';
 *
 * describe(aClass(MyClass), () => {
 *   describe(aSetter(MyClass, 'mySetter'), () => {
 *     it(`does what it's intended`, () => {
 *       // test...
 *     })
 *   })
 * })
 * ```
 */
export declare function aSetter<C extends ClassType | Func, M extends MethodName<C>>(_className: C, method: M): string;
/**
 *
 * @example
 * ```ts
 * import { myFunction } from './myHelpers.helpers.ts';
 *
 * describe(aFunction(myFunction), () => {
 *   it(`does what it's intended`, () => {
 *     // test...
 *   })
 * })
 * ```
 */
export declare function aFunction(func: Func): string;
/**
 *
 * @example
 * ```ts
 * import { myFactory } from './myHelpers.helpers.ts';
 *
 * describe(aFactory(myFactory), () => {
 *   it(`does what it's intended`, () => {
 *     // test...
 *   })
 * })
 * ```
 */
export declare function aFactory(factory: Func): string;
/** */
export declare function aFactoryMethod<M extends string>(factory: Func, method: M): string;
/** */
export declare function aComponent(component: {
    __name: string;
}): string;
/** */
export declare function snapshot(str: string | string[]): string;
