import { Func } from './Function.types';
import { KeysExcluding, KeysMatching, Obj } from './Object.types';
/** Type for TS instance narrowing */
export type ClassTyping<T extends string> = {
    __class__: T;
};
/** Type for a class that returns a given interface */
export type ClassType<T extends Obj = Obj> = Func & {
    name: string;
    new (...args: any[]): T;
};
/** Extracts the names of the static (class) methods of a given class */
export type StaticMethodName<C extends ClassType> = KeysMatching<C, Func>;
/** Extracts the names of the static (class) properties of a given class */
export type StaticPropsName<C extends ClassType> = KeysExcluding<C, Func>;
/** Extracts the names of the instance methods of a given class */
export type MethodName<C extends ClassType | Func> = keyof C['prototype'];
